==> nextcloud-13.0.1.tgz: nextcloud/apps/files_texteditor/l10n/el.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "γίνεται αποθήκευση...",
    "saved!" : "αποθηκεύτηκε!",
    "failed!" : "απέτυχε!",
    "Saved" : "Αποθηκεύτηκαν",
    "There was a problem saving your changes. Click to resume editing." : "Προέκυψε πρόβλημα κατά την αποθήκευση των αλλαγών σας. Κάντε κλικ για να συνεχίσετε την επεξεργασία.",
    "An error occurred!" : "Παρουσιάστηκε σφάλμα!",
    "Edit" : "Επεξεργασία",
    "Mixed" : "Μικτό",
    "Preview" : "Προεπισκόπηση",
    "New text file" : "Νέο αρχείο κειμένου",
    "New text file.txt" : "Νέο αρχείο κειμένου.txt",
    "You can not open a folder" : "Δεν μπορείτε να ανοίξετε ένα φάκελο",
    "This file is too big to be opened. Please download the file instead." : "Αυτό το αρχείο είναι πολύ μεγάλο για να ανοιχθεί. Αντί αυτού, παρακαλούμε κάντε λήψη του αρχείου.",
    "Cannot read the file." : "Αδυναμία ανάγνωσης αρχείου.",
    "Invalid file path supplied." : "Έχει δοθεί άκυρη διαδρομή για το αρχείο.",
    "The file is locked." : "Το αρχείο είναι κλειδωμένο.",
    "An internal server error occurred." : "Προέκυψε ένα εσωτερικό σφάλμα διακομιστή.",
    "You can not write to a folder" : "Δεν μπορείτε να γράψετε στον φάκελο",
    "Cannot save file as it has been modified since opening" : "Δεν είναι δυνατή η αποθήκευση του αρχείου, όπως έχει τροποποιηθεί από το άνοιγμα.",
    "Insufficient permissions" : "Μη επαρκή δικαιώματα",
    "File path not supplied" : "Η διαδρομή του αρχείου δεν παρέχεται.",
    "File mtime not supplied" : "Ο χρόνος τροποποίησης  του αρχείου δεν παρέχεται",
    "Text editor" : "Επεξεργαστής κειμένου"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.5.tgz: nextcloud/apps/files_texteditor/l10n/el.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "γίνεται αποθήκευση...",
    "saved!" : "αποθηκεύτηκε!",
    "failed!" : "απέτυχε!",
    "Saved" : "Αποθηκεύτηκαν",
    "There was a problem saving your changes. Click to resume editing." : "Προέκυψε πρόβλημα κατά την αποθήκευση των αλλαγών σας. Κάντε κλικ για να συνεχίσετε την επεξεργασία.",
    "An error occurred!" : "Παρουσιάστηκε σφάλμα!",
    "Edit" : "Επεξεργασία",
    "Mixed" : "Μικτό",
    "Preview" : "Προεπισκόπηση",
    "New text file" : "Νέο αρχείο κειμένου",
    "New text file.txt" : "Νέο αρχείο κειμένου.txt",
    "You can not open a folder" : "Δεν μπορείτε να ανοίξετε ένα φάκελο",
    "This file is too big to be opened. Please download the file instead." : "Αυτό το αρχείο είναι πολύ μεγάλο για να ανοιχθεί. Αντί αυτού, παρακαλούμε κάντε λήψη του αρχείου.",
    "Cannot read the file." : "Αδυναμία ανάγνωσης αρχείου.",
    "Invalid file path supplied." : "Έχει δοθεί άκυρη διαδρομή για το αρχείο.",
    "The file is locked." : "Το αρχείο είναι κλειδωμένο.",
    "An internal server error occurred." : "Προέκυψε ένα εσωτερικό σφάλμα διακομιστή.",
    "You can not write to a folder" : "Δεν μπορείτε να γράψετε στον φάκελο",
    "Cannot save file as it has been modified since opening" : "Δεν είναι δυνατή η αποθήκευση του αρχείου, όπως έχει τροποποιηθεί από το άνοιγμα.",
    "Could not write to file." : "Αδυναμία εγγραφής σε αρχείο.",
    "Insufficient permissions" : "Μη επαρκή δικαιώματα",
    "File path not supplied" : "Η διαδρομή του αρχείου δεν παρέχεται.",
    "File mtime not supplied" : "Ο χρόνος τροποποίησης  του αρχείου δεν παρέχεται",
    "Share not found" : "Δεν βρέθηκε το κονόχρηστο",
    "Text editor" : "Επεξεργαστής κειμένου"
},
"nplurals=2; plural=(n != 1);");
